@@ -6,8 +6,8 @@ class CommonMarkRenderer(Handler):
     Render CommonMarkup
     """
 
-    def __init__(self, url_base: str=None):
-        super().__init__(url_base=url_base)
+    def __init__(self, url_base: str=None, internal_hosts: list=None):
+        super().__init__(url_base=url_base, internal_hosts=internal_hosts)
 
     def new_paragraph(self, text: str):
         return text + self.line_feed()
@@ -22,7 +22,10 @@ class CommonMarkRenderer(Handler):
             return f"[{match.group(1)}]({match.group(2)}{match.group(3)})"
 
     def sub_url(self, match):
-        return f"[{match.group()}]({match.group()})"
+        if self._is_internal_address(match.group()):
+            return '<INTERN LENKE>'
+        else:
+            return f"[{match.group()}]({match.group()})"
 
     def sub_mail(self, match):
         return f"<mailto:{match.group()}>"
