@@ -8,8 +8,8 @@ class HTMLRenderer(Handler):
     Render HTML
     """
 
-    def __init__(self, url_base: str=None):
-        super().__init__(url_base=url_base)
+    def __init__(self, url_base: str=None, internal_hosts: list=None):
+        super().__init__(url_base=url_base, internal_hosts=internal_hosts)
 
     def new_paragraph(self, text: str):
         return "<p>\n" + text + "</p>" + self.line_feed()
@@ -42,7 +42,10 @@ class HTMLRenderer(Handler):
             return f"<a href={match.group(2)}{match.group(3)}>{match.group(1)}</a>"
 
     def sub_url(self, match):
-        return f'<a href={match.group()}>{match.group()}</a>'
+        if self._is_internal_address(match.group()):
+            return f'<INTERN LENKE>'
+        else:
+            return f'<a href={match.group()}>{match.group()}</a>'
 
     def sub_mail(self, match):
         return f'<a href=mailto:{match.group()}>{match.group()}</a>'
